setwd("/Users/agus/Dropbox/functional consequences of snake like body morph/Diversity")
require(phytools)
require(plyr)

# Prepare tree based on goicoechea 2017
tree=read.nexus("T108448.nex")
tree$tip.label
tree=drop.tip(tree,setdiff(tree$tip.label,c("Nothobachia_ablephara","Calyptommatus_sinebrachiatus","Calyptommatus_leiolepis","Calyptommatus_nicterus","Micrablepharus_atticolus","Micrablepharus_maximiliani","Tretioscincus_agilis","Vanzosaura_rubricauda","Procellosaurinus_erythrocercus","Procellosaurinus_tetradactylus" )))

plot(tree,
     no.margin=T,
     type = "clado",
     direction = "upwards",
     show.node.label=F,
     use.edge.length=F, 
     edge.width=3, 
     edge.color="green",
     label.offset=0.01,
     cex=1.5
     )



# prepare matrix for effects of morph on escape choice


# phylo analysis
require(readxl)
df<- data.frame(na.omit(read_excel("Supplementary file 1.xlsx",sheet=1)))
df$species <- factor(df$species)
df$option=as.numeric(as.character(df$option))

# Effects of environment and morph on escape strategy

#phylo mixed models
require(phyr)
l=strsplit(as.character(df$species),".",fixed = TRUE)
df$genus=do.call(rbind,l)[,1]

# from bury to hide 
df1=df[df$option!=3,]
dim(df1)
df1$option=as.factor(df1$option)
levels(df1$option)=c("0","1")
length(levels(as.factor(df$individual)))
df1$option=as.numeric(as.character(df1$option))
z <- pglmm(option~treatment*morph+(1|individual), 
           data = df1, family = "binomial", cov_ranef = list(sp = tree))
summary(z,ddf="Kenward-Rogers")

l=strsplit(as.character(df$species),".",fixed = TRUE)
df$genus=do.call(rbind,l)[,1]

# from hide to run
df1=df[df$option!=1,]
df1$option=as.factor(df1$option)
levels(df1$option)=c("0","1")
df1$option=as.numeric(as.character(df1$option))
z <-  pglmm(option~treatment*morph+(1|individual), 
           data = df1, family = "binomial", cov_ranef = list(sp = tree))
summary(z,ddf="Kenward-Rogers")

#  bury to run
df1=df[df$option!=2,]
df1$option=as.factor(df1$option)
levels(df1$option)=c("0","1")
df1$option=as.numeric(as.character(df1$option))
z <-  pglmm(option~treatment*morph+(1|individual), 
            data = df1, family = "binomial", cov_ranef = list(sp = tree))
summary(z,ddf="Kenward-Rogers")

# Non phylo models led to similar conclusions

df2=df[df$option!=3,]
df2$option=as.factor(df2$option)
levels(df2$option)=c("0","1")
df$treatment=factor(df$treatment)
m1<-glmer(option~treatment+morph+(1|individual)+(1|species),data=df2,family=binomial(link="logit"))
m2<-glmer(option~treatment+morph+(1|individual)+(1|genus),data=df2,family=binomial(link="logit"))
AIC(m1,m2)# better use species
summary(m1)
df2=df[df$option!=1,]
df2$option=as.factor(df2$option)
levels(df2$option)=c("0","1")
df$treatment=factor(df$treatment)
m1<-glmer(option~treatment+morph+(1|individual)+(1|species),data=df2,family=binomial(link="logit"))
m2<-glmer(option~treatment+morph+(1|individual)+(1|genus),data=df2,family=binomial(link="logit"))
AIC(m1,m2)# better use species
summary(m1)


summary(m2)

#plot
dt=df
dt$option=as.factor((dt$option))
levels(dt$option)=c("run","hide", "burrow")
head(dt)
dt$Morphotype=dt$morph
levels (dt$Morphotype)=c("Lacertoid","BSLM")

require(ggplot2)
win.metafile("f2.wmf",width=4,height=3.5,res=600)

#plot
dt$option=as.factor((dt$option))
levels(dt$option)=c("run","hide","burrow")
head(dt)
dt$Morphotype=dt$morph
levels (dt$Morphotype)=c("Lacertoid","BSLM")

win.metafile("f2.wmf",width=4,height=3.5,res=600)

ggplot(dt, aes(x=Morphotype, fill=option)) +
  geom_bar(position="fill") +
  scale_fill_manual(values=c("light blue","purple" ,"coral1")) +
  #  annotate("text", x=.5, y=1, label= "A") 
  ylab("Proportion of times used")+
  facet_grid(. ~ treatment, labeller=labeller(c("leaf litter, sand")))+
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position=c(0.76,0.75),
        legend.justification=c(1,1),
        legend.key = element_rect(fill = 'transparent',),
        legend.background = element_rect(fill = 'transparent',),
        legend.text = element_text(size = 9))

dev.off()




# Effects of Morphology and substrate on sprint speed on lizards.
# Limpar linhas ruins em excel e deixar com a estrutura da tabela lida abaixo

df<- data.frame((read_excel("Supplementary file 1.xlsx",sheet=2)))
df$species <- factor(df$species)

# preparation of variables
df$treatment=as.factor(df$treatment)
levels(df$treatment)=c("loose","hard")
# select max speed for each temperature and substrate
head(df)
require(dplyr)
dt <-
  df %>%
  group_by(individual,temperature,treatment, morph, species,) %>%
  summarise(topvel = max(speed))
# test
dim(dt)
z=(pglmm(topvel~treatment*morph+(1|individual), 
              data = dt, family = "gaussian", cov_ranef = list(sp = tree)))
summary(z,ddf="Kenward-Rogers")
# plot

dt$Morphotype=as.factor(dt$morph)
levels (dt$Morphotype)=c("Lacertoid","BSLM")

require(ggplot2)
#win.metafile("f3.wmf",width=4,height=3.5,res=600)
colnames(dt)
require(plyr)
newdf = data.frame(
  treatment = dt$treatment,
  morph=dt$morph,
  species=dt$species)# keep these fixed
head(newdf)
dt$species=as.factor(dt$species)
speed = ddply(dt,.(species,treatment),summarize,speed=mean(topvel))
head(speed)
newdf=merge(newdf,speed, by="species")


ggplot(newdf, aes(y=speed, x=treatment.y)) +
  geom_violin()+
  geom_line(data=newdf,aes(y=speed,x=treatment.y, group=species,colour=species),lwd=.5,lty=1)+

  ylab("Speed (cm/s)")+
  xlab("Temperature (\u00B0C)")+

  facet_grid(. ~ morph)+
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")


# Test and plot effects of prey speed and morph on predatory performance
df<- data.frame((read_excel("Supplementary file 1.xlsx",sheet=3)))
colnames(df)
dt=df[df$treatment%in%c("healthy","injured"),]
# Test
z=(pglmm(ingested~treatment*morph+(1|ind), data = dt, 
              family = "gaussian", cov_ranef = list(sp = tree)))
summary(z,ddf="Kenward-Rogers")
# Colors for plotting
dt$col=dt$morph
levels(dt$col)=c("ghostwhite","blue")# colors for posterior plotting

dt$morph=as.factor(dt$morph)
levels (dt$morph)=c("Lacertoid","BSLM")
dim(dt)

win.metafile("f4.wmf",width=4,height=3.5,res=600)

require(plyr)
newdf = data.frame(
  morph=dt$morph,
  species=dt$species)# keep these fixed
head(newdf)
dt$species=as.factor(dt$species)
y = ddply(dt,.(species,treatment,morph),summarize,y=mean(ingested))
head(y)
newdf=merge(newdf,y, by="species")
head(y$)
ggplot(y, aes(y=y, x=treatment)) +
  facet_grid(. ~ morph)+
  geom_violin()+
  geom_line(aes(y=y,group=species,colour=species),lwd=.5,lty=1)+
  ylab("ingested (m/s)")+
  xlab("prey type")+

  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")

dev.off()



# test and plot effects of surface active vs buried prey
# Test and plot effects of prey speed and morph on predatory performance
df<- data.frame((read_excel("Supplementary file 1.xlsx",sheet=3)))
colnames(df)
dt=df[df$treatment%in%c("up","down"),]

# Test
z=(pglmm(ingested~treatment*morph+(1|ind), data = dt, 
              family = "gaussian", cov_ranef = list(sp = tree)))
summary(z,ddf="Kenward-Rogers")

dt$morph=as.factor(dt$morph)
levels (dt$morph)=c("Lacertoid","BSLM")
dim(dt)
levels(dt$treatment)=c("buried","surface active")

win.metafile("f4b.wmf",width=4,height=3.5,res=600)

require(plyr)
newdf = data.frame(
  morph=dt$morph,
  species=dt$species)# keep these fixed
head(newdf)
dt$species=as.factor(dt$species)
y = ddply(dt,.(species,treatment,morph),summarize,y=mean(ingested))
head(y)
newdf=merge(newdf,y, by="species")
head(y$)
ggplot(y, aes(y=y, x=treatment)) +
  facet_grid(. ~ morph)+
  geom_violin()+
  geom_line(aes(y=y,group=species,colour=species),lwd=.5,lty=1)+
  ylab("ingested (m/s)")+
  xlab("prey type")+
  
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")
dev.off()

# test for the distribution of prey abundance and diversity in the field

# prepare dataset
# Test and plot effects of prey speed and morph on predatory performance
da<- data.frame((read_excel("Supplementary file 1.xlsx",sheet=4)))
head(da)
da$plot=seq(1, dim(da)[1])
da$habitat=as.factor(da$habitat)
levels(da$habitat)=c("Exposed", "Shaded")
levels(da$microhabitat)=c("Surface","Underground")
da$diversity
da$abundance
da$samplename
# Test
summary(glmer(diversity~habitat*microhabitat+(1|samplename), data = da, family = "poisson"))

summary(glmer(abundance~habitat*microhabitat+(1|samplename), data = da,family = "poisson"))

ggplot(da, aes(y=diversity, x=microhabitat, color=microhabitat))+
  geom_violin()+geom_line(aes(group=samplename), col="black",lty=2)+
  scale_color_manual(values=c("#999999", "#E69F00"))+
  ylab("Number of prey categories")+
  xlab("Microhabitat")+
  facet_grid(. ~ habitat)+
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")

ggplot(da, aes(y=abundance, x=microhabitat, color=microhabitat))+
  geom_violin()+geom_line(aes(group=samplename), col="black",lty=2)+
  
  scale_color_manual(values=c("#999999", "#E69F00"))+
  ylab("Number of prey items")+
  xlab("Microhabitat")+
  facet_grid(. ~ habitat)+
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")

# Analyze and plot lizards' abundance.

# Is BSLM abundance more impacted by soil type than lacertoid abundance?
df<- data.frame((read_excel("Supplementary file 1.xlsx",sheet=5)))
require(nlme)
require(pbkrtest)
head(df)
# how did sand availablity and habitat change across sites
df$soil.type=as.factor(df$soil.type)
df$site=as.factor(df$site)
dim(df)
head(df)
with(df,plot(as.factor(site),as.factor(habitat)))
with(df,plot(as.factor(site),as.factor(soil.type)))
df$site=factor(df$site)

print(summary(m,ddf="Kenward-Roger"))


dim(df)
z=(pglmm(ds.foss~soil.type*habitat+(1|site), data = df, 
         family = "gaussian", cov_ranef = list(sp = tree)))
summary(z,ddf="Kenward-Rogers")

z1=(pglmm(ds.lac~soil.type*habitat+(1|site), data = df, 
         family = "gaussian", cov_ranef = list(sp = tree)))
summary(z1,ddf="Kenward-Rogers")
dim(df)


# plot results
require(plyr)
ds=df[df$morph=="Lacertoid",]
y = ddply(ds,.(sp,habitat,soil.type),summarize,y=mean(abundance/plotsize))
head(y)
df1=merge(df,y,by=c("sp","soil.type","habitat"))
ggplot(df1, aes(y=ds.lac, x=soil.type))+
  geom_violin()+geom_line(aes(y=y,x=soil.type,group=sp, col=sp))+
  ylab(expression("Lacertoids' density (inds/m" ^ 2*")"))+
  xlab("Soil type")+
  facet_grid(. ~ habitat)+
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")

ds=df[df$morph=="BSLM",]
y = ddply(ds,.(sp,habitat,soil.type),summarize,y=mean(abundance/plotsize))
head(y)
df1=merge(df,y,by=c("sp","soil.type","habitat"))

ggplot(df1, aes(y=ds.lac, x=soil.type))+
  geom_violin()+geom_line(aes(y=y,x=soil.type,group=sp, col=sp))+
  ylab(expression("BSLM density (inds/m" ^ 2*")"))+
  xlab("Soil type")+
  facet_grid(. ~ habitat)+
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")







## Is BSLM abundance higher than of lacertoid cousins?
df<- data.frame((read_excel("Supplementary file 1.xlsx",sheet=6)))
df=df[df$ds.foss+df$ds.lac>0,]
dim(df)# 98 sites
df$site=factor(df$site);df$site

df<- data.frame((read_excel("Supplementary file 1.xlsx",sheet=5)))
df=df[df$totdens>0,]
df=df[df$ds.foss>0 & df$ds.lac>0,]
df$site=factor(df$site)
df$plot=factor(df$plot)

head(df)
dim(df)
df$site=factor(df$site)
z=(pglmm(abundance/plotsize~morph+(1|plot)+(1|site), data = df, 
         family = "gaussian", cov_ranef = list(sp = tree)))
summary(z,ddf="Kenward-Rogers")

# non phylogenetic approach renders similar value
z=(lmer(abundance/plotsize~morph+(1|plot)+(1|site), data = df))
summary(z,ddf="Kenward-Rogers")

y = ddply(df,.(sp,site),summarize,y=mean(abundance/plotsize))

df1=merge(df,y,by=c("sp","site"))
head(df1)
head(df)
ggplot(df1, aes(y=abundance/plotsize, x=morph))+
  geom_violin()+
  geom_point(aes(y=y,col=sp))+
  ylab(expression("Lizard density (inds/m" ^ 2*")"))+
  xlab("Morph")+
  facet_wrap(. ~ site,ncol = 2)+
  theme(panel.background = element_rect(fill='transparent', colour='black'),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.title.x = element_text(colour="black",size=12),
        axis.text.x  = element_text(angle=0, vjust=0.5,colour="black",size=11),
        axis.title.y = element_text(colour="black", size=12),
        axis.text.y  = element_text(angle=0, vjust=0.5,colour="black", size=11))+
  labs(fill="")+
  theme(strip.text.x = element_text(size=12, angle=0),
        strip.background = element_rect(colour="black", fill="white"))+
  theme(legend.position = "None")

plot size
390x295
